{% extends "layout.html.jinja2" %}
{% block title %}Tags Page | {{ tags }} | {{ title}} {% endblock %}
{% block content %}



    <div class="container">
     <div class="row">
      <div class="col-sm-10 offset-sm-1 col-md-9 offset-md-1 col-lg-8 offset-lg-2 col-xl-8 offset-lg-2">

<h2 class="tbh2"><br/>Blog Page | Tag: {{ tags }}</h2>
<br>


<br><br>
          {% for name in post %}
        <h3 class="tbh3">{{ post[name].metadata["title"] }}</h3>
          <p class="myptag">Posted on {{ post[name].metadata["date"] }}</p>
        <p>{{ post[name].summary }}</p></ul>
        <p class="myreadmore"><a href="/post/{{ post[name].path_info }}/{{ post[name].slug }}">Read More</a></p>
        <br><br>
        {% endfor %}


</div>
</div>
</div>




{% endblock %}