<p class="p-1 mb-0 bg-tbbg text-primary text-black text-center">
  <br/><br/> Powered by <a href="https://github.com/tatsatb/bestatic" target="_blank">Bestatic</a> | © Copyright Tatsat Banerjee | <a href="https://creativecommons.org/licenses/by-sa/4.0/" target="_blank">CC-BY-SA 4.0 License.</a> <br/><br/>
  <a href="https://www.facebook.com/" target="_blank"><i class="bi bi-facebook" style="font-size:36px"></i></a> &nbsp &nbsp
  <a href="https://www.linkedin.com/" target="_blank"><i class="bi bi-linkedin" style="font-size:36px"></i></a> &nbsp &nbsp
  <a href="https://www.twitter.com/" target="_blank"><i class="bi bi-twitter-x" style="font-size:36px"></i></a> &nbsp &nbsp
  <a href="https://www.github.com/" target="_blank"><i class="bi bi-github" style="font-size:36px"></i></a> &nbsp &nbsp
  <a href="mailto:example@example.org" target="_blank"><i class="bi bi-envelope-fill" style="font-size:36px"></i></a> <br/><br/><br/><br/>





  &nbsp &nbsp<a href="{{root_path}}"><img src="{{ Image_path }}/Bottom logo.png" width="194" height="135" alt="Home" /></a><br/><br/><br/>

</p>