{% extends "layout.html.jinja2" %}



{% block content %}

  <div class="container">


    <br/><br/>

    <div class="row">



      <div class="col-md-7 col-sm-12 mymarginright">

        <h3 class="tbh3">A Formal Introduction</h3>
        <br/>
        <p class="myptag" align="justify">


          Welcome! Welcome to my  official homepage!Let us put some example text here. What can be better than <a href="https://en.wikipedia.org/wiki/Lorem_ipsum"> Lorem ipsum </a> blocks?

      </p>
      <p class="myptag" align="justify">
        Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut tempus urna et mattis consequat. Vivamus malesuada arcu quis ligula commodo eleifend. Pellentesque sit amet lectus elit. Ut venenatis, metus in ultrices porttitor, purus ex blandit ligula, a eleifend lacus odio imperdiet quam. Pellentesque id turpis eleifend, sodales sapien et, ultrices mi. Duis varius ipsum ex, at finibus nibh ultrices ut. Ut eget lectus vulputate, mattis nisl eget, placerat quam. Well, you can always <a href="https://www.google.com">use Google to find </a> the genrators of Lorem ipsum block. You can easily link <a class="tbli" href="/Documents/ExampleDocument.pdf"> one of your documents in this website</a> or <a class="tbli" href="https://www.jhu.edu"> any other wesite</a>. Pellentesque ullamcorper mi eros, auctor finibus odio iaculis at. Nulla imperdiet urna in vehicula condimentum. Fusce tincidunt, lorem in hendrerit vulputate, ex nulla interdum velit, sit amet volutpat metus massa eu nibh.
        </p>


        <h4 class="tbh4">A heading here...</h4>
        <p class="myptag" align="justify">
        <br>Donec vestibulum convallis tempus. Nulla sit amet turpis pretium lorem feugiat efficitur. Praesent convallis lacus a mauris pulvinar, sit amet convallis urna convallis. Phasellus sit amet purus imperdiet, molestie diam vitae, ornare velit. In pharetra lobortis justo, sit amet maximus velit malesuada eget. Vivamus sed rutrum massa. Aenean et tellus eu justo gravida consequat. Duis in ultrices elit. Nunc tortor ex, consectetur non scelerisque eu, ullamcorper vel dolor. Vestibulum lobortis turpis leo, non mollis tellus sollicitudin eget. Mauris ut lorem id tortor dictum posuere. Ut orci magna, tristique quis arcu eu, venenatis faucibus tellus. Nullam porttitor cursus dolor, non vulputate justo iaculis sed. Duis ante diam, volutpat quis vehicula quis, commodo eu leo. Donec euismod turpis at nulla lobortis pretium. Nulla luctus, erat eget fermentum sagittis, elit sapien feugiat arcu, sit amet eleifend lacus orci vel neque.
        </p>
        <h4 class="tbh4">Let's put another heading here...</h4>
        <p class="myptag" align="justify">
         Nullam sed porttitor lorem. Vivamus aliquet vestibulum tellus id ornare. Duis sagittis ligula in dictum iaculis. Praesent leo eros, porttitor eget pulvinar ac, mollis in diam. Nunc malesuada nisl sed justo rhoncus vulputate ut ut eros. Quisque convallis magna non eleifend dictum. Curabitur sodales mattis erat, rhoncus sagittis elit cursus eget. Aliquam sed magna vitae eros lacinia egestas sed id nisi. Morbi id hendrerit neque. Nullam hendrerit non orci id cursus. Suspendisse consequat eleifend elementum. Nunc id diam rutrum, tempus magna ut, porta orci. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
        </p>
        <h4 class="tbh4">Here is yet another heading...</h4>
        <p class="myptag" align="justify">
          <br>Vivamus pellentesque nunc ac mauris molestie, ut vestibulum turpis molestie. Duis in dolor mi. Donec sed luctus enim. Curabitur varius neque turpis, et aliquet velit dignissim id. </p>
        <h4 class="tbh4">Et Cetra...</h4>
        <p class="myptag" align="justify">
          In vel laoreet ipsum, non feugiat augue. Suspendisse porttitor lorem nec tellus consectetur, nec varius leo venenatis. Curabitur id finibus ipsum. Nam id odio egestas ipsum pellentesque tempus vel nec orci. Suspendisse et ultricies ligula. Maecenas mauris odio, fermentum vel blandit et, molestie faucibus leo. Duis diam neque, suscipit ut mattis non, scelerisque at enim. Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.
          <br/><br/>
          If you want to see another demo of this theme, then please visit:
          <br><br>
          </p>
          <p align="center">
          <strong><a href="http://www.tatsatbanerjee.in">www.tatsatbanerjee.in</a></strong> <br/><br/>
          </p>
          <p class="myptag" align="justify">
          And last, but not the least quick point to mention: Thanks a ton for visiting this Hugo theme demo page!! Always feel free to fork the project!
          </p>


      </div>

      <div class="col-md-5 col-sm-12 mymarginleft">
        <h3 class="tbh3">A Few (informal) Snapshots</h3>


			<h4 class="text-nowrap tbh4"><br/>How does a cartoon look<br/></h4>
			      <div class="polaroid">

                      <img src="static/Images/Young1.png" style="height: 460px" width="290" alt="Tatsat Banerjee - An old image" />
                      <p style="left: 0px; bottom: 50px; width: 92%">One (not-so) old Photo</p>
                  </div>

			<h4 class="tbh4"><br/><br/>What I believe<br/></h4>

			<blockquote class="blockquote">
				<p>&#8220;This is another awesome placeholder quote. Please replace these with your own!&#8221;
				<cite class="tbcite">
				<a href="https://www.tatsatbanerjee.in/"> Firstname Lastname</a></cite></p>
				<p>&#8220;Much of Linux's success can be attrib­uted to my own personality flaws: 1) I'm lazy; and 2) I like to get credit for the work of others. &#8221;
				<cite class="tbcite">
				<a href="https://en.wikipedia.org/wiki/Linus_Torvalds">Linus Torvalds</a></cite></p>
				<p>&#8220;With software there are only two possibilites: either the users control the programme or the programme controls the users. &#8221;
				<cite class="tbcite">
				<a href="https://stallman.org/">Richard Stallman</a></cite></p>
				<p>&#8220;Veritas liberabit vos (the truth shall set you free)&#8221;
				<cite class="tbcite">
				<a href="https://en.wikipedia.org/wiki/Gospel_of_John">Gospel of John</a></cite></p>
				<p>&#8220;एकं सद्विप्रा बहुधा वदन्ति  (The Truth is one; it is narrated in various ways)&#8221;
				<cite class="tbcite">
				<a href="https://en.wikipedia.org/wiki/Rigveda">ऋग्वेद (Rigveda)</a></cite></p>
				<p>&nbsp;</p>


			</blockquote>

        <h4 class="tbh4">Recommended Places to Visit</h4>

			<ul>
			<br>
				<li><a class="tbli" href="https://www.debian.org/" >Debian, a great Linux distro</a></li>
				<li><a class="tbli" href="https://gohugo.io/">Hugo, a great static site generator</a></li>
				<li><a class="tbli" href="https://kde.org/">KDE Plasma, a great desktop environment</a></li>
				<li><a class="tbli" href="https://www.tatsatbanerjee.in">Another TatBanTheme2.0 Demo Site</a></li>
			</ul>




      </div>






    </div>

  </div>

{% endblock %}
