<header class="headercool">
      <div class="container">
      <div class="row">
        <div class="col-12 text-center">

            <a href="/"><img src="{{ Image_path }}/Logo_1.png" class="img-fluid" alt="Tatsat Banerjee" /></a>

        </div>





      </div>
    </div>

    </header>

</script>