{% extends "layout.html.jinja2" %}
{% block title %} Error 404: Page not found! {% endblock %}

{% block content %}
<div class="container">
    <div class="row">
      <div class="col-sm-10 offset-sm-1 col-md-9 offset-md-1 col-lg-8 offset-lg-2 col-xl-8 offset-lg-2">



      <div>
          <br/><br/>
       <h3 id="title" class="tbh3"><a href="{{ root_path }}/index.html">Return to homepage</a></h3>
       <p>Sorry, the requested page is not available on our website. <br> Please click above to return to homepage.</p>
      </div>




</div>
</div>
</div>
{% endblock %}